==========
Change log
==========

For an overview of what has changed between versions, see the :ref:`changelog`.


.. _changelog:

0.1.4 2023-06-14
-----------------

- Only show dropdown in menu if more then one item
- Added dark mode template to Plotly charts controlled by cookie
- Added default spinner for chart loading
- Added gauge component

0.1.3 2023-05-23
-----------------

updated default styles

0.1.2 2023-05-17
-----------------

added `template_id` for unique component keys in templates.

0.1.1 2023-05-14
-----------------

Initial public release